Authors
=======

Sangjoon Lee, Emil Jaffal, Danila Shiryaev, Nikhil Kumar Barua, Alex Vtorov, Anton Oliynyk

Contributors
------------

For a list of contributors, visit
https://github.com/bobleesj/composition-analyzer-featurizer/graphs/contributors
